@@ -19,11 +19,11 @@ else:
     class BassBoostConverter(Transformer):
         @classmethod
         async def convert(cls, ctx: PyLavContext, arg: str) -> str:
-            """Converts user input to a valid argument for the bassboost command."""
+            """Converts user input to a valid argument for the bassboost command"""
             from pylav import EntryNotFoundError
 
             try:
-                match = next(
+                if match := next(
                     filter(
                         lambda x: x.lower().startswith(arg.lower()),
                         [
@@ -39,12 +39,12 @@ else:
                         ],
                     ),
                     None,
-                )
-                if not match:
+                ):
+                    return match
+                else:
                     raise EntryNotFoundError
-                return match
             except EntryNotFoundError as e:
-                raise commands.BadArgument(_("Bass boost with name `{arg}` not found.").format(arg=arg)) from e
+                raise commands.BadArgument(_("Bass boost with name `{arg}` not found").format(arg=arg)) from e
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> str:
