@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 import itertools
 from io import BytesIO
 from pathlib import Path
@@ -413,7 +414,8 @@ class EnqueuePlaylistButton(discord.ui.Button):
         if hasattr(self.view, "prepare"):
             await self.view.prepare()
             kwargs = await self.view.get_page(self.view.current_page)
-            await context.message.edit(view=self.view, **kwargs)
+            with contextlib.suppress(discord.HTTPException):
+                await context.message.edit(view=self.view, **kwargs)
 
 
 class SaveQueuePlaylistButton(discord.ui.Button):
